using SciChart.Charting.ChartModifiers;
using SciChart.Charting.Visuals;
using SciChart.Charting.Visuals.Annotations;
using SciChart.Charting.Visuals.RenderableSeries;
using SciChart.Charting.Model.ChartSeries;
﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using SciChart.Core;
using SciChart.Data;
using SciChart.Drawing;
using SciChart.Drawing.DirectX;
using SciChart.Charting;
using SciChart.Charting.Model.DataSeries;

using SciChart.Charting.Model.DataSeries;

using SciChart.Charting.Model.DataSeries;
using WpfTestExample.Annotations;

namespace WpfTestExample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window, INotifyPropertyChanged
    {
        private ObservableCollection<IChartSeriesViewModel> _graphicsCollection;
        private AnnotationCollection _annotationCollection;
        private bool _isCheckedDisplay;

        public ObservableCollection<IChartSeriesViewModel> GraphicsCollection
        {
            get { return _graphicsCollection; }
            set
            {
                if (_graphicsCollection != value)
                {
                    _graphicsCollection = value;
                    OnPropertyChanged("GraphicsCollection");
                }
            }
        }

        public AnnotationCollection AnnotationCollection
        {
            get { return _annotationCollection; }
            set
            {
                _annotationCollection = value;
                OnPropertyChanged("AnnotationCollection");
            }
        }


        public MainWindow()
        {
            InitializeComponent();
            AnnotationCollection = new AnnotationCollection();
            GraphicsCollection=new ObservableCollection<IChartSeriesViewModel>();

        }

        private void LoadedData()
        {
            DataContext = this;
            AddSeriesToChart();
        }

        private void AddSeriesToChart()
        {
            var firstDataSeries = GetFirstDataSeries(0,1);
            var secondDataSeries = GetFirstDataSeries(2,2);
            GraphicsCollection.Add(new ChartSeriesViewModel(firstDataSeries,new FontSizeTroubleDisplaySeries() {Stroke = Colors.Red,FontSize = 16, CustomText = "1abcdef3", SelectedSeriesStyle =new Style(typeof(FontSizeTroubleDisplaySeries)) {Setters = { new Setter(BaseRenderableSeries.StrokeProperty,Colors.Pink) }} }));
            GraphicsCollection.Add(new ChartSeriesViewModel(secondDataSeries,new FontSizeTroubleDisplaySeries() {Stroke = Colors.Red,FontSize = 12,CustomText = "2bhelo1" , SelectedSeriesStyle = new Style(typeof(FontSizeTroubleDisplaySeries)) { Setters = { new Setter(BaseRenderableSeries.StrokeProperty, Colors.Pink) } } }));
        }

        private IDataSeries<double, double> GetFirstDataSeries(int beginPoint, int multiplyData)
        {
            var dataSeries=new XyDataSeries<double, double>();
            dataSeries.Append(beginPoint+0, 0);
            dataSeries.Append(beginPoint+2 * multiplyData,2*multiplyData);
            dataSeries.Append(beginPoint+5 * multiplyData,5*multiplyData);
            return dataSeries;
        }

        private void SciChartSurface_Loaded(object sender, RoutedEventArgs e)
        {
            LoadedData();
        }


        public event PropertyChangedEventHandler PropertyChanged;

        [NotifyPropertyChangedInvocator]
        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            var handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }

}
